==> eiffelstudio-19.05.10.3187.tar: F_code/C1/an1.h <==

#ifndef _C1_an1_
#define _C1_an1_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1_4(EIF_REFERENCE);
extern EIF_REFERENCE F1_5(EIF_REFERENCE);
extern EIF_BOOLEAN F1_7(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_8(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_10(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);
extern void F1_15(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_16(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_20(EIF_REFERENCE);
extern void F1_23(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,24)
static EIF_REFERENCE F1_24_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_24(EIF_REFERENCE);
extern EIF_REFERENCE F1_25(EIF_REFERENCE);
extern EIF_REFERENCE F1_26(EIF_REFERENCE);
extern void F1_27(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,28)
static EIF_REFERENCE F1_28_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_28(EIF_REFERENCE);
extern void F1_29(EIF_REFERENCE);
extern void F1_30(EIF_REFERENCE);
extern void F1_31(EIF_REFERENCE);
extern EIF_POINTER F1_33(EIF_REFERENCE);
extern void EIF_Minit1(void);
extern void F724_9949(EIF_REFERENCE, EIF_REFERENCE);
extern void F2216_21671(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F155_2764(EIF_REFERENCE);
extern EIF_REFERENCE F155_2761(EIF_REFERENCE);
extern void F2218_21780(EIF_REFERENCE, EIF_REFERENCE);
RTOSHF(EIF_REFERENCE,2761)
extern char *(*R11[])();
extern char *(*R15210[])();
extern char *(*R11110[])();
extern char *(*R28[])();
extern char *(*R11041[])();

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C1/an1.h <==

#ifndef _C1_an1_
#define _C1_an1_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1_5(EIF_REFERENCE);
extern EIF_BOOLEAN F1_7(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_8(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_9(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_10(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);
extern void F1_15(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_16(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_23(EIF_REFERENCE);
static EIF_REFERENCE F1_24_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_24(EIF_REFERENCE);
extern EIF_REFERENCE F1_25(EIF_REFERENCE);
extern EIF_REFERENCE F1_26(EIF_REFERENCE);
extern void F1_27(EIF_REFERENCE, EIF_REFERENCE);
static EIF_REFERENCE F1_28_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_28(EIF_REFERENCE);
extern void F1_29(EIF_REFERENCE);
extern void F1_30(EIF_REFERENCE);
extern void F1_31(EIF_REFERENCE);
extern EIF_POINTER F1_33(EIF_REFERENCE);
extern void EIF_Minit1(void);
extern void F103_1944(EIF_REFERENCE, EIF_REFERENCE);
extern void F103_1942(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1182_10285(EIF_REFERENCE);
extern void F1187_10471(EIF_REFERENCE, EIF_REFERENCE);
extern void F103_1939(EIF_REFERENCE);
extern void F358_5217(EIF_REFERENCE, EIF_REFERENCE);
extern void F1185_10358(EIF_REFERENCE, EIF_REFERENCE);
extern char *(*R11[])();
extern char *(*R9487[])();
extern char *(*R28[])();
extern char *(*R6057[])();

#ifdef __cplusplus
}
#endif

#endif
